@@ -1,13 +1,14 @@
-/* A Bison parser, made by GNU Bison 3.0.4.  */
+/* A Bison parser, made by GNU Bison 2.3.  */
 
-/* Bison interface for Yacc-like parsers in C
+/* Skeleton interface for Bison's Yacc-like parsers in C
 
-   Copyright (C) 1984, 1989-1990, 2000-2015 Free Software Foundation, Inc.
+   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006
+   Free Software Foundation, Inc.
 
-   This program is free software: you can redistribute it and/or modify
+   This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation, either version 3 of the License, or
-   (at your option) any later version.
+   the Free Software Foundation; either version 2, or (at your option)
+   any later version.
 
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -15,7 +16,9 @@
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
+   along with this program; if not, write to the Free Software
+   Foundation, Inc., 51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301, USA.  */
 
 /* As a special exception, you may create a larger work that contains
    part or all of the Bison parser skeleton and distribute that work
@@ -30,42 +33,34 @@
    This special exception was added by the Free Software Foundation in
    version 2.2 of Bison.  */
 
-#ifndef YY_YY_PARSER_H_INCLUDED
-# define YY_YY_PARSER_H_INCLUDED
-/* Debug traces.  */
-#ifndef YYDEBUG
-# define YYDEBUG 0
-#endif
-#if YYDEBUG
-extern int yydebug;
-#endif
-
-/* Token type.  */
+/* Tokens.  */
 #ifndef YYTOKENTYPE
 # define YYTOKENTYPE
-  enum yytokentype
-  {
-    COMMA = 258,
-    DICE = 259,
-    DIV = 260,
-    FUDGE = 261,
-    HIGH = 262,
-    LCURLY = 263,
-    LOW = 264,
-    LPAREN = 265,
-    MINUS = 266,
-    PERCENT = 267,
-    PLUS = 268,
-    RCURLY = 269,
-    RPAREN = 270,
-    TIMES = 271,
-    LE = 272,
-    LT = 273,
-    GE = 274,
-    GT = 275,
-    NE = 276,
-    NUMBER = 277
-  };
+   /* Put the tokens into the symbol table, so that GDB and other debuggers
+      know about them.  */
+   enum yytokentype {
+     COMMA = 258,
+     DICE = 259,
+     DIV = 260,
+     FUDGE = 261,
+     HIGH = 262,
+     LCURLY = 263,
+     LOW = 264,
+     LPAREN = 265,
+     MINUS = 266,
+     PERCENT = 267,
+     PLUS = 268,
+     RCURLY = 269,
+     RPAREN = 270,
+     TIMES = 271,
+     X = 272,
+     LE = 273,
+     LT = 274,
+     GE = 275,
+     GT = 276,
+     NE = 277,
+     NUMBER = 278
+   };
 #endif
 /* Tokens.  */
 #define COMMA 258
@@ -82,34 +77,31 @@ extern int yydebug;
 #define RCURLY 269
 #define RPAREN 270
 #define TIMES 271
-#define LE 272
-#define LT 273
-#define GE 274
-#define GT 275
-#define NE 276
-#define NUMBER 277
+#define X 272
+#define LE 273
+#define LT 274
+#define GE 275
+#define GT 276
+#define NE 277
+#define NUMBER 278
+
+
+
 
-/* Value type.  */
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
-
-union YYSTYPE
+typedef union YYSTYPE
+#line 38 "parser.y"
 {
-#line 23 "parser.y" /* yacc.c:1909  */
-
   struct ir_node * node;
   int              int_type;
-
-#line 103 "parser.h" /* yacc.c:1909  */
-};
-
-typedef union YYSTYPE YYSTYPE;
-# define YYSTYPE_IS_TRIVIAL 1
+}
+/* Line 1529 of yacc.c.  */
+#line 100 "parser.h"
+	YYSTYPE;
+# define yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
+# define YYSTYPE_IS_TRIVIAL 1
 #endif
 
-
 extern YYSTYPE yylval;
 
-int yyparse (void);
-
-#endif /* !YY_YY_PARSER_H_INCLUDED  */
